@@ -94,7 +94,7 @@ global_properties_init (GnomePropertyObject *object)
 	if (prop_ptr->save_session)
 		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button), TRUE);
 
-	cb_data = g_new (RadioButtonCbData, 1);
+	cb_data = g_new0 (RadioButtonCbData, 1);
 	cb_data->button = button;
 	cb_data->object = object;
 
@@ -106,7 +106,7 @@ global_properties_init (GnomePropertyObject *object)
 	gtk_container_add (GTK_CONTAINER (frame), table);
 	gtk_box_pack_start (GTK_BOX (vb), frame, FALSE, TRUE, 0);
 
-	frame = gtk_frame_new (_("Update times (notebook pages)"));
+	frame = gtk_frame_new (_("Update times"));
 	table = gtk_table_new (3, 3, FALSE);
 	gtk_container_border_width (GTK_CONTAINER (table), GNOME_PAD);
 	gtk_table_set_row_spacings (GTK_TABLE (table), GNOME_PAD_SMALL);
@@ -397,7 +397,7 @@ global_properties_init (GnomePropertyObject *object)
 	if (prop_ptr->mdi_mode == GNOME_MDI_NOTEBOOK)
 		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button), TRUE);
 
-	cb_data = g_new (RadioButtonCbData, 1);
+	cb_data = g_new0 (RadioButtonCbData, 1);
 	cb_data->button = button;
 	cb_data->object = object;
 	cb_data->index = GNOME_MDI_NOTEBOOK;
@@ -412,7 +412,7 @@ global_properties_init (GnomePropertyObject *object)
 	if (prop_ptr->mdi_mode == GNOME_MDI_TOPLEVEL)
 		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button), TRUE);
 
-	cb_data = g_new (RadioButtonCbData, 1);
+	cb_data = g_new0 (RadioButtonCbData, 1);
 	cb_data->button = button;
 	cb_data->object = object;
 	cb_data->index = GNOME_MDI_TOPLEVEL;
@@ -427,7 +427,7 @@ global_properties_init (GnomePropertyObject *object)
 	if (prop_ptr->mdi_mode == GNOME_MDI_MODAL)
 		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button), TRUE);
 
-	cb_data = g_new (RadioButtonCbData, 1);
+	cb_data = g_new0 (RadioButtonCbData, 1);
 	cb_data->button = button;
 	cb_data->object = object;
 	cb_data->index = GNOME_MDI_MODAL;
@@ -487,6 +487,12 @@ global_properties_load (GnomePropertyObject *object)
 
 	gtop_properties.global.update_times [GTOP_UPDATE_DETAILS] =
 		gnome_config_get_int ("gtop/global/update_details=3000");
+
+	gtop_properties.global.show_menubar =
+		gnome_config_get_int ("gtop/global/show_menubar=1");
+
+	gtop_properties.global.show_toolbar =
+		gnome_config_get_int ("gtop/global/show_toolbar=1");
 }
 
 static void
@@ -543,4 +549,12 @@ global_properties_save (GnomePropertyObject *object)
 	gnome_config_set_int
 		("gtop/global/update_details",
 		 gtop_properties.global.update_times [GTOP_UPDATE_DETAILS]);
+
+	gnome_config_set_int
+		("gtop/global/show_menubar",
+		 gtop_properties.global.show_menubar);
+
+	gnome_config_set_int
+		("gtop/global/show_toolbar",
+		 gtop_properties.global.show_toolbar);
 }
