@@ -44,7 +44,7 @@ guint		gtop_memusage_get_type	(void);
 
 extern GnomeMDI *mdi;
 
-extern gchar *gtop_memusage_type_labels[];
+extern GnomeUIInfo gtop_memusage_radio_items [];
 
 END_GNOME_DECLS
 
