@@ -83,7 +83,7 @@ static const GdkColor load_defaults [2] = {
                
 static GtkAdjustment *max_loadavg_adjustment;
 
-#define STATUSBAR_DEFAULT_FONT "-*-courier-medium-r-*-*-12-*-*-*-m-*-*-*"
+#define STATUSBAR_DEFAULT_FONT "-*-*-medium-r-*-*-12-*-*-*-*-*-*-*"
 
 static void update_font (GtkWidget *widget);
 
@@ -441,8 +441,8 @@ gtop_summary_unmap (GTopSummaryData *d)
 	gnome_proc_bar_stop (GNOME_PROC_BAR (d->summary_load));
 }
 
-void
-gtop_summary_destroy (GTopSummaryData *d)
+static void
+summary_destroy_cb (GtkWidget *summary, GTopSummaryData *d)
 {
 	gtop_summary_unmap (d);
 
@@ -490,6 +490,9 @@ gtop_summary_new (void)
 
 	summary_object_list = g_list_append (summary_object_list, d);
 
+	gtk_signal_connect (GTK_OBJECT (d->summary), "destroy",
+			    summary_destroy_cb, d);
+
 	return d;
 }
 
@@ -612,6 +615,24 @@ statusbar_mem_cb (gpointer label)
 	return TRUE;
 }
 
+static void
+statusbar_destroy_cb (GtkWidget *status_bar, GTopStatusBarData *d)
+{
+	if (d->status_cpu_timeout > 0)
+		gtk_timeout_remove (d->status_cpu_timeout);
+
+	if (d->status_mem_timeout > 0)
+		gtk_timeout_remove (d->status_mem_timeout);
+
+	if (d->status_uptime_timeout > 0)
+		gtk_timeout_remove (d->status_uptime_timeout);
+
+	if (d->status_loadavg_timeout > 0)
+		gtk_timeout_remove (d->status_loadavg_timeout);
+
+	statusbar_object_list = g_list_remove (statusbar_object_list, d);
+}
+
 GTopStatusBarData *
 gtop_statusbar_new (void)
 {
@@ -704,6 +725,9 @@ gtop_statusbar_new (void)
 
 	statusbar_object_list = g_list_append (statusbar_object_list, d);
 
+	gtk_signal_connect (GTK_OBJECT (d->status_bar), "destroy",
+			    statusbar_destroy_cb, d);
+
 	return d;
 }
 
@@ -817,24 +841,6 @@ gtop_statusbar_update (GTopStatusBarData *d)
 	}
 }
 
-void
-gtop_statusbar_destroy (GTopStatusBarData *d)
-{
-	if (d->status_cpu_timeout > 0)
-		gtk_timeout_remove (d->status_cpu_timeout);
-
-	if (d->status_mem_timeout > 0)
-		gtk_timeout_remove (d->status_mem_timeout);
-
-	if (d->status_uptime_timeout > 0)
-		gtk_timeout_remove (d->status_uptime_timeout);
-
-	if (d->status_loadavg_timeout > 0)
-		gtk_timeout_remove (d->status_loadavg_timeout);
-
-	statusbar_object_list = g_list_remove (statusbar_object_list, d);
-}
-
 /* =======================================================================
  * Summary properties code.
  * =======================================================================
@@ -932,7 +938,7 @@ summary_properties_init (GnomePropertyObject *object)
 	if (summary_mode & (1 << GTOP_SUMMARY_SHOW_GRAPH))
 		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (label), TRUE);
 
-	cb_data = g_new (RadioButtonCbData, 1);
+	cb_data = g_new0 (RadioButtonCbData, 1);
 	cb_data->index = GTOP_SUMMARY_SHOW_GRAPH;
 	cb_data->button = label;
 	cb_data->object = object;
@@ -949,7 +955,7 @@ summary_properties_init (GnomePropertyObject *object)
 	if (summary_mode & (1 << GTOP_SUMMARY_GRAPH_CPU))
 		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (label), TRUE);
 
-	cb_data = g_new (RadioButtonCbData, 1);
+	cb_data = g_new0 (RadioButtonCbData, 1);
 	cb_data->index = GTOP_SUMMARY_GRAPH_CPU;
 	cb_data->button = label;
 	cb_data->object = object;
@@ -966,7 +972,7 @@ summary_properties_init (GnomePropertyObject *object)
 	if (summary_mode & (1 << GTOP_SUMMARY_GRAPH_XCPU))
 		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (label), TRUE);
 
-	cb_data = g_new (RadioButtonCbData, 1);
+	cb_data = g_new0 (RadioButtonCbData, 1);
 	cb_data->index = GTOP_SUMMARY_GRAPH_XCPU;
 	cb_data->button = label;
 	cb_data->object = object;
@@ -983,7 +989,7 @@ summary_properties_init (GnomePropertyObject *object)
 	if (summary_mode & (1 << GTOP_SUMMARY_GRAPH_MEM))
 		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (label), TRUE);
 
-	cb_data = g_new (RadioButtonCbData, 1);
+	cb_data = g_new0 (RadioButtonCbData, 1);
 	cb_data->index = GTOP_SUMMARY_GRAPH_MEM;
 	cb_data->button = label;
 	cb_data->object = object;
@@ -1000,7 +1006,7 @@ summary_properties_init (GnomePropertyObject *object)
 	if (summary_mode & (1 << GTOP_SUMMARY_GRAPH_SWAP))
 		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (label), TRUE);
 
-	cb_data = g_new (RadioButtonCbData, 1);
+	cb_data = g_new0 (RadioButtonCbData, 1);
 	cb_data->index = GTOP_SUMMARY_GRAPH_SWAP;
 	cb_data->button = label;
 	cb_data->object = object;
@@ -1017,7 +1023,7 @@ summary_properties_init (GnomePropertyObject *object)
 	if (summary_mode & (1 << GTOP_SUMMARY_GRAPH_LOAD))
 		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (label), TRUE);
 
-	cb_data = g_new (RadioButtonCbData, 1);
+	cb_data = g_new0 (RadioButtonCbData, 1);
 	cb_data->index = GTOP_SUMMARY_GRAPH_LOAD;
 	cb_data->button = label;
 	cb_data->object = object;
@@ -1072,7 +1078,7 @@ summary_properties_init (GnomePropertyObject *object)
 	if (summary_mode & (1 << GTOP_SUMMARY_SHOW_TEXT))
 		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (label), TRUE);
 
-	cb_data = g_new (RadioButtonCbData, 1);
+	cb_data = g_new0 (RadioButtonCbData, 1);
 
 	cb_data->index = GTOP_SUMMARY_SHOW_TEXT;
 	cb_data->button = label;	
@@ -1087,7 +1093,7 @@ summary_properties_init (GnomePropertyObject *object)
 	if (summary_mode & (1 << GTOP_SUMMARY_TEXT_STATUSBAR))
 		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (label), TRUE);
 
-	cb_data = g_new (RadioButtonCbData, 1);
+	cb_data = g_new0 (RadioButtonCbData, 1);
 	cb_data->index = GTOP_SUMMARY_TEXT_STATUSBAR;
 	cb_data->button = label;
 	cb_data->object = object;
@@ -1100,7 +1106,7 @@ summary_properties_init (GnomePropertyObject *object)
 	if (summary_mode & (1 << GTOP_SUMMARY_TEXT_HOSTNAME))
 		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (label), TRUE);
 
-	cb_data = g_new (RadioButtonCbData, 1);
+	cb_data = g_new0 (RadioButtonCbData, 1);
 	cb_data->index = GTOP_SUMMARY_TEXT_HOSTNAME;
 	cb_data->button = label;
 	cb_data->object = object;
@@ -1113,7 +1119,7 @@ summary_properties_init (GnomePropertyObject *object)
 	if (summary_mode & (1 << GTOP_SUMMARY_TEXT_USE_FQDN))
 		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (label), TRUE);
 
-	cb_data = g_new (RadioButtonCbData, 1);
+	cb_data = g_new0 (RadioButtonCbData, 1);
 	cb_data->index = GTOP_SUMMARY_TEXT_USE_FQDN;
 	cb_data->button = label;
 	cb_data->object = object;
@@ -1126,7 +1132,7 @@ summary_properties_init (GnomePropertyObject *object)
 	if (summary_mode & (1 << GTOP_SUMMARY_TEXT_CPU))
 		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (label), TRUE);
 
-	cb_data = g_new (RadioButtonCbData, 1);
+	cb_data = g_new0 (RadioButtonCbData, 1);
 	cb_data->index = GTOP_SUMMARY_TEXT_CPU;
 	cb_data->button = label;
 	cb_data->object = object;
@@ -1142,7 +1148,7 @@ summary_properties_init (GnomePropertyObject *object)
 	if (summary_mode & (1 << GTOP_SUMMARY_TEXT_MEMORY))
 		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (label), TRUE);
 
-	cb_data = g_new (RadioButtonCbData, 1);
+	cb_data = g_new0 (RadioButtonCbData, 1);
 	cb_data->index = GTOP_SUMMARY_TEXT_MEMORY;
 	cb_data->button = label;
 	cb_data->object = object;
@@ -1158,7 +1164,7 @@ summary_properties_init (GnomePropertyObject *object)
 	if (summary_mode & (1 << GTOP_SUMMARY_TEXT_SWAP))
 		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (label), TRUE);
 
-	cb_data = g_new (RadioButtonCbData, 1);
+	cb_data = g_new0 (RadioButtonCbData, 1);
 	cb_data->index = GTOP_SUMMARY_TEXT_SWAP;
 	cb_data->button = label;
 	cb_data->object = object;
@@ -1174,7 +1180,7 @@ summary_properties_init (GnomePropertyObject *object)
 	if (summary_mode & (1 << GTOP_SUMMARY_TEXT_UPTIME))
 		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (label), TRUE);
 
-	cb_data = g_new (RadioButtonCbData, 1);
+	cb_data = g_new0 (RadioButtonCbData, 1);
 	cb_data->index = GTOP_SUMMARY_TEXT_UPTIME;
 	cb_data->button = label;
 	cb_data->object = object;
@@ -1190,7 +1196,7 @@ summary_properties_init (GnomePropertyObject *object)
 	if (summary_mode & (1 << GTOP_SUMMARY_TEXT_LOADAVG))
 		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (label), TRUE);
 
-	cb_data = g_new (RadioButtonCbData, 1);
+	cb_data = g_new0 (RadioButtonCbData, 1);
 	cb_data->index = GTOP_SUMMARY_TEXT_LOADAVG;
 	cb_data->button = label;
 	cb_data->object = object;
@@ -1232,14 +1238,14 @@ summary_properties_load (GnomePropertyObject *object)
 	gtop_properties.summary.statusbar_font_name =
 		gnome_config_get_string (name);
 
-	gtop_properties.summary.statusbar_font = gdk_font_load
+	gtop_properties.summary.statusbar_font = gdk_fontset_load
 		(gtop_properties.summary.statusbar_font_name);
 
 	if (!gtop_properties.summary.statusbar_font) {
 		g_free (gtop_properties.summary.statusbar_font_name);
 		gtop_properties.summary.statusbar_font_name =
 			g_strdup (STATUSBAR_DEFAULT_FONT);
-		gtop_properties.summary.statusbar_font = gdk_font_load
+		gtop_properties.summary.statusbar_font = gdk_fontset_load
 			(gtop_properties.summary.statusbar_font_name);
 	}
 
